@@ -83,7 +83,6 @@ class TestDevice:
             assert device.get_firmware() == "2.680.0000000.25.R.220527"
             assert device.is_online() is True
             self.loop.run_until_complete(device.async_get_data())
-            assert device.get_sensor_by_name("lastAlarm").get_state() == "2022-09-25T17:36:33"
             assert device.get_sensor_by_name("online").is_on() is True
             assert device.get_sensor_by_name("breathingLight").is_on() is True
             assert device.get_sensor_by_name("localRecord").is_on() is True
@@ -118,21 +117,6 @@ class TestDevice:
             sensor = device.get_sensor_by_name("unknown")
             assert sensor is None
 
-    def test_get_alarm_malformed(self):
-        """Test get alarm message: malformed."""
-        with aioresponses() as mocked:
-            self.config_mock(mocked, "accessToken", "accessToken_ok")
-            self.config_mock(mocked, "deviceBaseDetailList", "deviceBaseDetailList_ok")
-            device = ImouDevice(self.api_client, "8L0DF93PAZ55FD2")
-            self.loop.run_until_complete(device.async_initialize())
-            self.config_mock(mocked, "deviceOnline", "deviceOnline_ok", repeat=True)
-            self.config_mock(mocked, "getAlarmMessage", "getAlarmMessage_malformed")
-            self.config_mock(mocked, "getDeviceCameraStatus", "getDeviceCameraStatus_ok", repeat=True)
-            self.config_mock(mocked, "getMessageCallback", "getMessageCallback_ok", repeat=True)
-            with pytest.raises(Exception) as exception:
-                self.loop.run_until_complete(device.async_get_data())
-            assert "InvalidResponse" in str(exception)
-
     def test_get_online_malformed(self):
         """Test get alarm message: malformed."""
         with aioresponses() as mocked:
